====================
Py-ART documentation
====================

Welcome, this is the documentation for the Python ARM Radar Toolkit (Py-ART).

Latest Release
==============

.. toctree::
    :maxdepth: 1

    user_reference/index
    dev_reference/index
    auto_examples/index

The files used in the examples are available for download_.

.. _download: https://engineering.arm.gov/~jhelmus/pyart_example_data/
